==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/gems/dialogs_nl.lua <==

dialogId("zav-v-sto", "font_big", "Please note, that this level contains one hundred and nine objects.")
dialogStr("Bedenk even dat dit veld honderdnegen objecten bevat.")


dialogId("zav-v-trpyt", "font_big", "And all of them gleam beautifully.")
dialogStr("En ze glinsteren allemaal zo mooi.")


dialogId("zav-m-pohnout", "font_small", "Please note, that I can`t move a fin here.")
dialogStr("Bedenk even dat ik geen vin kan verroeren.")


dialogId("zav-m-krasa", "font_small", "It`s beautiful! Everything gleams so much...")
dialogStr("Het is prachtig! Alles glinstert zo...")


dialogId("zav-v-venku", "font_big", "It`ll be much nicer when we get out.")
dialogStr("Het zou veel fijner zijn als we hieruit konden komen.")


dialogId("zav-v-zaval", "font_big", "This is very dangerous cave-in. We are lucky to be alive.")
dialogStr("Dat was een gevaarlijke instorting. We hebben geluk dat we nog leven.")


dialogId("zav-m-hopskok", "font_small", "Don`t speak too soon. We`re still in here.")
dialogStr("Preis de dag niet voor het avond is. We zitten hier nogsteeds opgesloten.")


dialogId("zav-m-kameny", "font_small", "Don`t you think that these stones are arranged in a different way?")
dialogStr("Denk je niet dat deze stenen anders liggen?")


dialogId("zav-v-zeleny", "font_big", "You are right. That green one was surely over there!")
dialogStr("Je hebt gelijk. Die groene daar lag eerst in ieder geval ergens anders.")


dialogId("zav-v-restart", "font_big", "I think that these jewels arrange themselves in a different way after each restart.")
dialogStr("Ik denk dat deze kristallen na elk keer herstarten anders liggen.")


dialogId("zav-m-pravda", "font_small", "Yeah, you`re right. Maybe they form some sensible pattern sometimes.")
dialogStr("Inderdaad. Misschien vormen ze soms wel een zinvol patroon.")


dialogId("zav-m-hrac", "font_small", "Look, our player obviously satiated his need for colors.")
dialogStr("Kijk, onze speler heeft duidelijk genoeg kleurtjes gezien.")


dialogId("zav-v-zachranit", "font_big", "Maybe he could try to save us instead now.")
dialogStr("Misschien kan hij of zij ons dan nu gaan redden.")

==> fillets-ng-data_0.9.2.orig.tar.gz: fillets-ng-data-0.9.2/script/gems/dialogs_nl.lua <==

dialogId("zav-v-sto", "font_big", "Please note, that this level contains one hundred and nine objects.")
dialogStr("Sta even stil bij het feit dat dit veld honderdnegen objecten bevat.")


dialogId("zav-v-trpyt", "font_big", "And all of them gleam beautifully.")
dialogStr("En ze glinsteren allemaal zo mooi.")


dialogId("zav-m-pohnout", "font_small", "Please note, that I can’t move a fin here.")
dialogStr("Sta even stil bij het feit dat ik geen vin kan verroeren.")


dialogId("zav-v-venku", "font_big", "It’ll be much nicer when we get out.")
dialogStr("Het zal vast veel worden zijn als we hier weg zijn.")


dialogId("zav-v-zaval", "font_big", "This is very dangerous cave-in. We are lucky to be alive.")
dialogStr("Dat was een gevaarlijke instorting. We hebben geluk dat we nog leven.")


dialogId("zav-m-hopskok", "font_small", "Don’t speak too soon. We’re still in here.")
dialogStr("Preis de dag niet voor het avond is. We zitten hier nogsteeds opgesloten.")


dialogId("zav-m-kameny", "font_small", "Don’t you think that these stones are arranged in a different way?")
dialogStr("Denk je niet dat deze stenen anders liggen?")


dialogId("zav-v-zeleny", "font_big", "You are right. That green one was surely over there!")
dialogStr("Je hebt gelijk. Die groene daar lag eerst in ieder geval ergens anders.")


dialogId("zav-v-restart", "font_big", "I think that these jewels arrange themselves in a different way after each restart.")
dialogStr("Ik denk dat deze kristallen na elk keer herstarten anders liggen.")


dialogId("zav-m-pravda", "font_small", "Yeah, you’re right. Maybe they form some sensible pattern sometimes.")
dialogStr("Inderdaad. Misschien vormen ze soms wel een zinvol patroon.")


dialogId("zav-m-hrac", "font_small", "Look, our player obviously satiated his need for colors.")
dialogStr("Kijk, onze speler heeft duidelijk genoeg kleurtjes gezien.")


dialogId("zav-v-zachranit", "font_big", "Maybe he could try to save us instead now.")
dialogStr("Misschien kan hij of zij ons dan nu gaan redden.")
